@@ -15,7 +15,7 @@ from mandeintegration.config.types import ExpenditureReport, ExpenditureReportDe
 from datetime import datetime
 
 
-__version__ = '0.1.0'
+# __version__ = '0.1.5'
 
 
 @classmethod
@@ -196,7 +196,19 @@ class MandEIntegration:
         def format_country(country: str) -> str:
             return "NE" if country.upper() == "NIGER" else "US"
         
-        project = Project(code, name, start_date, end_date, format_amount(budget_total_amount), status, grant_type, format_country(country))
+        def format_date(date: str) -> str:
+            return datetime.strftime(datetime.strptime(date, '%m/%d/%Y'), '%Y-%m-%d').strip() if date else ""
+        
+        def format_status(status: str) -> str:
+            return status.upper().replace(" ", "").strip() if status else ""
+        
+        def format_name(name: str) -> str:
+            return name.lower().strip() if name else ""
+        
+        def format_code(code: str) -> str:
+            return f"USADF-{code.strip()}" if code else ""
+        
+        project = Project(format_code(code), format_name(name), format_date(start_date), format_date(end_date), format_amount(budget_total_amount), format_status(status), grant_type, format_country(country))
         
         return project
     
